@@ -829,7 +829,7 @@ def get_record_details_from_crm(vtiger_access, data):
             id = element.get('id', '')
             if id:
                 # prepare query id using source module
-                record_id = "{module}x{record_id}".format(module=module_id, record_id=id)
+                record_id = id if "x" in id else "{module}x{record_id}".format(module=module_id, record_id=id)
 
                 user_id_list.append(record_id)
         print("user id list received: ", user_id_list)
